package cn.estsh.i3plus.core.apiservice.controller;

import cn.estsh.i3plus.core.api.iservice.busi.ISystemResourceService;
import cn.estsh.i3plus.platform.common.convert.ConvertBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.enumutil.ResourceEnumUtil;
import cn.estsh.i3plus.pojo.base.bean.ListPager;
import cn.estsh.i3plus.pojo.platform.bean.SessionUser;
import cn.estsh.impp.framework.boot.auth.AuthUtil;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ResultBean;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.platform.bean.SysLocaleLanguage;
import cn.estsh.i3plus.pojo.platform.bean.SysLocaleResource;
import cn.estsh.impp.framework.boot.exception.ImppBusiException;
import cn.estsh.impp.framework.boot.exception.ImppExceptionEnum;
import cn.estsh.impp.framework.boot.util.ImppRedis;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Locale;

/**
 * @Description : 系统资源服务demo
 * @Reference :
 * @Author : alwaysfrin
 * @CreateDate : 2018-09-26 10:34
 * @Modify:
 **/
@RestController
@RequestMapping("/demo-system-service")
@Api(description="系统服务demo")
public class DemoSystemController {
    private static final Logger LOGGER = LoggerFactory.getLogger(DemoSystemController.class);

    /**
     * 缓存
     */
    @Resource(name="redisCore")
    private ImppRedis redisCore;

    /**
     * rabbitMQ队列
     */
    @Autowired
    private RabbitTemplate rabbitTemplate;

    @Autowired
    private ISystemResourceService systemResourceService;

    @PutMapping(value="/language/insert")
    @ApiOperation(value="添加语言",notes = "添加系统语言，可用于国际化")
    public ResultBean insertLanguage(SysLocaleLanguage lang) {
        try {
            //登陆用户
            SessionUser user = AuthUtil.getSessionUser();

            //条件验证
            ValidatorBean.beginValid(lang)
                    .notNull("languageName",lang.getLanguageName())
                    .notNull("languageCode",lang.getLanguageCode());

            //新增初始化
            ConvertBean.modelInitialize(lang,user);

            systemResourceService.insertSysLocaleLanguage(lang);
            return ResultBean.success("操作成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            LOGGER.error(busExcep.getErrorMsg() + "：{}",busExcep.getErrorDetail(),busExcep);
            return ResultBean.fail(busExcep.getErrorShow()).build();
        }catch(Exception e){
            return ResultBean.fail(e.getMessage()).setCode(ImppExceptionEnum.SYSTEM_EXCEPTION.getCode());
        }
    }

    @PutMapping(value="/language/update")
    @ApiOperation(value="修改语言",notes = "修改系统语言，可用于国际化")
    public ResultBean updateLanguage(SysLocaleLanguage lang) {
        try {
            //登陆用户
            SessionUser user = AuthUtil.getSessionUser();

            //条件验证
            ValidatorBean.beginValid(lang)
                    .notNull("languageName",lang.getLanguageName())
                    .notNull("languageCode",lang.getLanguageCode());

            //修改条件
            ConvertBean.modelUpdate(lang,user);
            systemResourceService.updateSysLocaleLanguage(lang);
            return ResultBean.success("修改成功").setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            LOGGER.error(busExcep.getErrorMsg() + "：{}",busExcep.getErrorDetail(),busExcep);
            return ResultBean.fail(busExcep.getErrorShow()).build();
        }catch(Exception e){
            return ResultBean.fail(e.getMessage()).setCode(ImppExceptionEnum.SYSTEM_EXCEPTION.getCode());
        }
    }

    @PutMapping(value="/language/query")
    @ApiOperation(value="查询语言",notes = "添加系统语言，可用于国际化")
    public ResultBean queryLanguage(SysLocaleLanguage lang,Pager pager) {
        try {
            ListPager listPager = systemResourceService.listSysLocaleLanguageByPager(lang,pager);
            return ResultBean.success("操作成功").setListPager(listPager).setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            LOGGER.error(busExcep.getErrorMsg() + "：{}",busExcep.getErrorDetail(),busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        }catch(Exception e){
            LOGGER.error(ImppExceptionEnum.SYSTEM_EXCEPTION.getDescription() + "：{}",e.getMessage(),e);
            return ResultBean.fail().setCode(ImppExceptionEnum.SYSTEM_EXCEPTION.getCode());
        }
    }

    @PutMapping(value="/resource/insert")
    @ApiOperation(value="添加资源",notes = "添加系统语言，可用于国际化")
    public ResultBean insertResource(SysLocaleResource res) {
        try {
            //登陆用户
            SessionUser user = AuthUtil.getSessionUser();

            //条件验证
            ValidatorBean.beginValid(res)
                    .notNull("resourceKey",res.getResourceKey())
                    .notNull("resourceValue",res.getResourceValue());

            //新增初始化
            ConvertBean.modelInitialize(res,user);
            systemResourceService.insertSysLocaleResource(res);
            return ResultBean.success("操作成功")
                                .setResultObject(res)
                                .setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            LOGGER.error(busExcep.getErrorMsg() + "：{}",busExcep.getErrorDetail(),busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        }catch(Exception e){
            LOGGER.error(ImppExceptionEnum.SYSTEM_EXCEPTION.getDescription() + "：{}",e.getMessage(),e);
            return ResultBean.fail().setCode(ImppExceptionEnum.SYSTEM_EXCEPTION.getCode());
        }
    }

    @PutMapping(value="/resource/query")
    @ApiOperation(value="查询资源",notes = "分页查询系统资源")
    public ResultBean queryResource(SysLocaleResource res,Pager pager) {
        try{
            ListPager listPager = systemResourceService.listSysLocaleResourceByPager(res,pager);
            return ResultBean.success("操作成功")
                                .setListPager(listPager)
                                .setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            LOGGER.error(busExcep.getErrorMsg() + "：{}",busExcep.getErrorDetail(),busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        }catch(Exception e){
            LOGGER.error(ImppExceptionEnum.SYSTEM_EXCEPTION.getDescription() + "：{}",e.getMessage(),e);
            return ResultBean.fail().setCode(ImppExceptionEnum.SYSTEM_EXCEPTION.getCode());
        }
    }

    @GetMapping(value="/locale-resource/get")
    @ApiOperation(value="语言资源匹配",notes="资源配置文件及国际化")
    public ResultBean getLocaleResource(int resourceType,String langCode,String resKey) {
        try {
            ValidatorBean.checkNotZero(resourceType,"请选择资源类型。");
            ValidatorBean.checkNotNull(langCode,"请输入语言编码");
            ValidatorBean.checkNotNull(resKey,"请输入资源编码");
            Locale locale = LocaleContextHolder.getLocale();
            LOGGER.info("当前语言：" + locale.getLanguage() + "，国家：" + locale.getCountry());

            SysLocaleResource res = systemResourceService.getSysLocaleResourceByLanguage(resourceType, langCode, resKey);
            LOGGER.info("获取的资源：" + res);

            return ResultBean.success("保存成功")
                                .setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode())
                                .setResultObject(res);
        }catch(ImppBusiException busExcep){
            LOGGER.error(busExcep.getErrorMsg() + "：{}",busExcep.getErrorDetail(),busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        }catch(Exception e){
            LOGGER.error(ImppExceptionEnum.SYSTEM_EXCEPTION.getDescription() + "：{}",e.getMessage(),e);
            return ResultBean.fail().setCode(ImppExceptionEnum.SYSTEM_EXCEPTION.getCode());
        }
    }

    @DeleteMapping  (value="/locale-resource/delete")
    @ApiOperation(value="删除资源",notes="批量删除资源")
    public ResultBean deleteLocaleResource(String[] resourceIds) {
        try {
            if(resourceIds.length == 0){
                throw ImppExceptionBuilder.newInstance()
                        .setSystemID(CommonEnumUtil.SOFT_TYPE.IMPP.getCode())
                        .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                        .setErrorDetail("请选择需要删除的资源。")
                        .build();
            }
            systemResourceService.deleteSysLocaleResourceByIds(resourceIds);

            return ResultBean.success().setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        }catch(ImppBusiException busExcep){
            LOGGER.error(busExcep.getErrorMsg() + "：{}",busExcep.getErrorDetail(),busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        }catch(Exception e){
            LOGGER.error(ImppExceptionEnum.SYSTEM_EXCEPTION.getDescription() + "：{}",e.getMessage(),e);
            return ResultBean.fail().setCode(ImppExceptionEnum.SYSTEM_EXCEPTION.getCode());
        }
    }

}
