 package cn.estsh.i3plus.core.apiservice.controller.busi;

 import cn.estsh.i3plus.core.api.iservice.busi.ISysMenuService;
 import cn.estsh.i3plus.pojo.platform.bean.SessionUser;
 import cn.estsh.i3plus.pojo.platform.bean.SysMenu;
 import cn.estsh.i3plus.pojo.platform.bean.SysUser;
 import cn.estsh.impp.framework.boot.auth.AuthUtil;
 import cn.estsh.impp.framework.boot.exception.ImppBusiException;
 import cn.estsh.impp.framework.boot.exception.ImppExceptionEnum;
 import cn.estsh.impp.framework.boot.util.ResultBean;
 import io.swagger.annotations.Api;
 import io.swagger.annotations.ApiOperation;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.web.bind.annotation.*;

 import java.util.List;

/**
 * @Description : 系统功能对外接口
 * @Reference :
 * @Author : wei.peng
 * @Date : 2018-10-22 15:18:14.982
 * @Modify :
 **/
@RestController
@RequestMapping("/sys-menu")
@Api(description = "系统功能服务")
public class SysMenuController {

    public static final Logger LOGGER = LoggerFactory.getLogger(SysMenuController.class);

    @Autowired
    private ISysMenuService sysMenuService;

    @PostMapping(value = "/insert")
    @ApiOperation(value = "新增系统功能", notes = "系统功能")
    public ResultBean insertSysMenu(SysMenu sysMenu) {
        try {
            SysMenu menu = sysMenuService.insertSysMenu(sysMenu);
            return new ResultBean(true,menu);
        } catch(ImppBusiException busExcep){
            LOGGER.error(busExcep.getErrorMsg() + "：{}",busExcep.getErrorDetail(),busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        }catch(Exception e){
            LOGGER.error(ImppExceptionEnum.BUSINESS_EXCEPTION_DATA_ERROR.getDescription() + "：{}",e.getMessage(),e);
            return ResultBean.fail().setCode(ImppExceptionEnum.BUSINESS_EXCEPTION_DATA_ERROR.getCode());
        }
    }

    @PutMapping(value = "/update")
    @ApiOperation(value = "修改系统功能", notes = "系统功能")
    public ResultBean updateSysMenu(SysMenu sysMenu) {
        if(null == sysMenu || null == sysMenu.getId()){
            return new ResultBean(false, "操作失败","对象id不能为空为空");
        }
        sysMenuService.updateSysMenu(sysMenu);
        return new ResultBean(true, "操作成功", sysMenu);
    }

    @DeleteMapping(value = "/delete")
    @ApiOperation(value = "删除系统功能", notes = "删除系统功能")
    public ResultBean deleteSysMenu(long id) {
        try {
            sysMenuService.deleteSysMenuById(id);
             return new ResultBean(true);
        } catch(ImppBusiException busExcep){
            LOGGER.error(busExcep.getErrorMsg() + "：{}",busExcep.getErrorDetail(),busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        }catch(Exception e){
            LOGGER.error(ImppExceptionEnum.BUSINESS_EXCEPTION_DATA_ERROR.getDescription() + "：{}",e.getMessage(),e);
            return ResultBean.fail().setCode(ImppExceptionEnum.BUSINESS_EXCEPTION_DATA_ERROR.getCode());
        }
    }

    @GetMapping(value = "/findSysMenuAll")
    @ApiOperation(value = "查询SysMenu", notes = "查询所有系统功能")
    public ResultBean findSysMenuAll() {
        List<SysMenu> list = sysMenuService.findSysMenuAll();
        return new ResultBean(true, "操作成功", list);
    }

    @GetMapping(value = "/getSysMenu/{id}")
    @ApiOperation(value = "查询系统功能", notes = "查询根据ID查询系统功能")
    public ResultBean getBySysMenuId(@PathVariable("id") long id) {
        SysMenu sysMenu = sysMenuService.getSysMenuById(id);
        return new ResultBean(true, "操作成功", sysMenu);
    }

    @PutMapping(value = "/updateStatus")
    @ApiOperation(value = "修改权限状态", notes = "根据ID修改权限状态")
    public ResultBean updateStatus(long id,int status) {
        try {
            sysMenuService.updateSysMenuStatus(id,status,AuthUtil.getSessionUser());
            return new ResultBean(true);
        } catch(ImppBusiException busExcep){
            LOGGER.error(busExcep.getErrorMsg() + "：{}",busExcep.getErrorDetail(),busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        }catch(Exception e){
            LOGGER.error(ImppExceptionEnum.BUSINESS_EXCEPTION_DATA_ERROR.getDescription() + "：{}",e.getMessage(),e);
            return ResultBean.fail().setCode(ImppExceptionEnum.BUSINESS_EXCEPTION_DATA_ERROR.getCode());
        }
    }


}
