package cn.estsh.i3plus.core.apiservice.controller.busi;

import cn.estsh.i3plus.core.api.iservice.busi.ISysRoleService;
import cn.estsh.i3plus.pojo.platform.bean.SessionUser;
import cn.estsh.i3plus.pojo.platform.bean.SysRole;
import cn.estsh.i3plus.pojo.platform.bean.SysUser;
import cn.estsh.impp.framework.boot.auth.AuthUtil;
import cn.estsh.impp.framework.boot.exception.ImppBusiException;
import cn.estsh.impp.framework.boot.exception.ImppExceptionEnum;
import cn.estsh.impp.framework.boot.util.ResultBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Description : 系统角色对外接口
 * @Reference :
 * @Author : wei.peng
 * @Date : 2018-10-22 16:58:43.790
 * @Modify :
 **/
@RestController
@RequestMapping("/sys-role")
@Api(description = "系统角色服务")
public class SysRoleController {

    public static final Logger LOGGER = LoggerFactory.getLogger(SysRoleController.class);


    @Autowired
    private ISysRoleService sysRoleService;

    @PostMapping(value = "/insert")
    @ApiOperation(value = "新增系统角色", notes = "系统角色")
    public ResultBean insertSysRole(SysRole sysRole) {
        try {
            SysRole role = sysRoleService.insertSysRole(sysRole);
            return new ResultBean(true, role);
        } catch (ImppBusiException busExcep) {
            LOGGER.error(busExcep.getErrorMsg() + "：{}", busExcep.getErrorDetail(), busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        } catch (Exception e) {
            LOGGER.error(ImppExceptionEnum.BUSINESS_EXCEPTION_DATA_ERROR.getDescription() + "：{}", e.getMessage(), e);
            return ResultBean.fail().setCode(ImppExceptionEnum.BUSINESS_EXCEPTION_DATA_ERROR.getCode());
        }
    }

    @PutMapping(value = "/update")
    @ApiOperation(value = "修改系统角色", notes = "系统角色")
    public ResultBean updateSysRole(SysRole sysRole) {
        sysRoleService.updateSysRole(sysRole);
        return new ResultBean(true, "操作成功", sysRole);
    }

    @DeleteMapping(value = "/delete")
    @ApiOperation(value = "删除系统角色", notes = "删除系统角色")
    public ResultBean deleteSysRole(long id) {
        sysRoleService.deleteSysRoleById(id);
        return new ResultBean(true, "操作成功");
    }

    @GetMapping(value = "/findSysRoleAll")
    @ApiOperation(value = "查询SysRole", notes = "查询所有系统角色")
    public ResultBean findSysRoleAll() {
        List<SysRole> list = sysRoleService.findSysRoleAll();
        return new ResultBean(true, "操作成功", list);
    }

    @GetMapping(value = "/getSysRole/{id}")
    @ApiOperation(value = "查询系统角色", notes = "查询根据ID查询系统角色")
    public ResultBean getBySysRoleId(@PathVariable("id") long id) {
        SysRole sysRole = sysRoleService.getSysRoleById(id);
        return new ResultBean(true, "操作成功", sysRole);
    }

    @PutMapping(value = "/updateStatus")
    @ApiOperation(value = "修改权限状态", notes = "根据ID修改权限状态")
    public ResultBean updateStatus(long id, int status) {
        try {

            sysRoleService.updateSysRoleStatus(id, status, AuthUtil.getSessionUser());
            return new ResultBean(true);
        } catch (ImppBusiException busExcep) {
            LOGGER.error(busExcep.getErrorMsg() + "：{}", busExcep.getErrorDetail(), busExcep);
            return ResultBean.fail(busExcep.getErrorShow());
        } catch (Exception e) {
            LOGGER.error(ImppExceptionEnum.BUSINESS_EXCEPTION_DATA_ERROR.getDescription() + "：{}", e.getMessage(), e);
            return ResultBean.fail().setCode(ImppExceptionEnum.BUSINESS_EXCEPTION_DATA_ERROR.getCode());
        }
    }
}
