package cn.estsh.i3plus.core.apiservice.listener;

import cn.estsh.i3plus.core.api.iservice.busi.ISystemResourceService;
import cn.estsh.i3plus.core.apiservice.util.ConstWords;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.platform.bean.SysLocaleLanguage;
import cn.estsh.i3plus.pojo.platform.bean.SysLocaleResource;
import cn.estsh.impp.framework.boot.util.ImppRedis;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationListener;
import org.springframework.context.event.ContextRefreshedEvent;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;

/**
 * @Description : 初始化资源配置
 * @Reference :
 * @Author : alwaysfrin
 * @CreateDate : 2018-10-12 18:43
 * @Modify:
 **/
public class SysResourceBindleListener implements ApplicationListener<ContextRefreshedEvent> {
    private static final Logger LOGGER = LoggerFactory.getLogger(SysResourceBindleListener.class);

    @Autowired
    public ISystemResourceService systemResourceService;

    @Resource(name="redisCore")
    private ImppRedis redisCore;

    @Override
    public void onApplicationEvent(ContextRefreshedEvent contextRefreshedEvent) {
        List<SysLocaleLanguage> langList = systemResourceService.listSysLocaleLanguage(null);
        LOGGER.info("【加载平台资源】共有{}种语言。",langList.size());

        List<SysLocaleResource> resourceList = null;
        SysLocaleResource resource = null;
        //模块集合
        HashMap<String,HashMap<String,String>> langModoleMap = new HashMap();
        //功能集合
        HashMap<String,HashMap<String,String>> langMethodMap = new HashMap();
        //按钮集合
        HashMap<String,HashMap<String,String>> langBtnMap = new HashMap();
        //信息集合
        HashMap<String,HashMap<String,String>> langMsgMap = new HashMap();
        //资源集合
        HashMap<String,String> resMap;

        /************** 加载国际化 *************/
        for(SysLocaleLanguage lang : langList) {

            /************** 加载模块 *************/
            resource = new SysLocaleResource();
            resource.setResourceType(CommonEnumUtil.SYS_LOCALE_RESOURCE_TYPE.MODULE.getValue());
            resource.setLanguageCode(lang.getLanguageCode());
            resourceList = systemResourceService.listSysLocaleResource(resource);

            LOGGER.info("【{}-{},{}】共有{}个资源。",CommonEnumUtil.SYS_LOCALE_RESOURCE_TYPE.MODULE.getDescription(),
                                    lang.getLanguageName(),lang.getLanguageCode(),resourceList.size());
            resMap = new HashMap<String,String>();
            for(SysLocaleResource res : resourceList){
                resMap.put(res.getResourceKey(),res.getResourceValue());
            }
            langModoleMap.put(lang.getLanguageCode(),resMap);

            /************** 加载功能 *************/
            resource = new SysLocaleResource();
            resource.setResourceType(CommonEnumUtil.SYS_LOCALE_RESOURCE_TYPE.METHOD.getValue());
            resource.setLanguageCode(lang.getLanguageCode());
            resourceList = systemResourceService.listSysLocaleResource(resource);

            LOGGER.info("【{}-{},{}】共有{}个资源。",CommonEnumUtil.SYS_LOCALE_RESOURCE_TYPE.METHOD.getDescription(),
                                    lang.getLanguageName(),lang.getLanguageCode(),resourceList.size());
            resMap = new HashMap<String,String>();
            for(SysLocaleResource res : resourceList){
                resMap.put(res.getResourceKey(),res.getResourceValue());
            }
            langMethodMap.put(lang.getLanguageCode(),resMap);

            /************** 加载按钮 *************/
            resource = new SysLocaleResource();
            resource.setResourceType(CommonEnumUtil.SYS_LOCALE_RESOURCE_TYPE.BUTTON.getValue());
            resource.setLanguageCode(lang.getLanguageCode());
            resourceList = systemResourceService.listSysLocaleResource(resource);

            LOGGER.info("【{}-{},{}】共有{}个资源。",CommonEnumUtil.SYS_LOCALE_RESOURCE_TYPE.BUTTON.getDescription(),
                                    lang.getLanguageName(),lang.getLanguageCode(),resourceList.size());
            resMap = new HashMap<String,String>();
            for(SysLocaleResource res : resourceList){
                resMap.put(res.getResourceKey(),res.getResourceValue());
            }
            langBtnMap.put(lang.getLanguageCode(),resMap);

            /************** 加载资源 *************/
            resource = new SysLocaleResource();
            resource.setResourceType(CommonEnumUtil.SYS_LOCALE_RESOURCE_TYPE.COMMON.getValue());
            resource.setLanguageCode(lang.getLanguageCode());
            resourceList = systemResourceService.listSysLocaleResource(resource);

            LOGGER.info("【{}-{},{}】共有{}个资源。",CommonEnumUtil.SYS_LOCALE_RESOURCE_TYPE.COMMON.getDescription(),
                                    lang.getLanguageName(),lang.getLanguageCode(),resourceList.size());
            resMap = new HashMap<String,String>();
            for(SysLocaleResource res : resourceList){
                resMap.put(res.getResourceKey(),res.getResourceValue());
            }
            langMsgMap.put(lang.getLanguageCode(),resMap);
        }

        redisCore.putHashMap(ConstWords.PLAT_MODULE_PREX,langModoleMap);
        redisCore.putHashMap(ConstWords.PLAT_MODULE_METHOD_PREX,langMethodMap);
        redisCore.putHashMap(ConstWords.PLAT_MODULE_BUTTON_PREX,langBtnMap);
        redisCore.putHashMap(ConstWords.LANGUAGE_CONVERT_PREX,langMsgMap);

        LOGGER.info("【资源配置文件已全部加载】");
    }
}
