package cn.estsh.i3plus.core.apiservice.mq;

import com.rabbitmq.client.Channel;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.stereotype.Component;

import java.io.IOException;

/**
 * @Description : 获取队列信息后处理
 * @Reference :
 * @Author : alwaysfrin
 * @CreateDate : 2018-09-26 10:40
 * @Modify:
 **/
@Component
public class I3CoreQueueReceiver {

    /*@RabbitListener(queues = I3CoreQueue.DEMO_STR_QUEUE)
    public void getObjQueue(String data) {
        System.out.println("接收数据  : " + data.toString());
    }

    @RabbitListener(queues = I3CoreQueue.DEMO_OBJ_QUEUE)
    public void getStrQueue(MachineFactory data) {
        System.out.println("强转对象：" + data);
    }*/

    @RabbitListener(queues = I3CoreQueue.DEMO_RETURN_QUEUE)
    public Message processReturn(String data, Channel channel, Message message) {
        try {
            System.out.println("【client】数据接收成功：" + data);
            Thread.sleep(1000);

            //告诉服务器收到这条消息 已经被我消费了 可以在队列删掉 这样以后就不会再发了 否则消息服务器以为这条消息没处理掉 后续还会在发
            //消息的标识，false只确认当前一个消息收到，true确认所有consumer获得的消息

            channel.basicAck(message.getMessageProperties().getDeliveryTag(),false);
        } catch (Exception e) {
            System.out.println("出现异常：" + e.getMessage());
            // 错误反馈
            // val1 = 是否批量.true:将一次性拒绝所有小于deliveryTag的消息。
            // val2 = 被拒绝的是否重新列入队列
            try {
                channel.basicNack(message.getMessageProperties().getDeliveryTag(), false,true);
            } catch (IOException e1) {
                e1.printStackTrace();
            }
            //拒绝，同basicNack，只是没有批量这个属性
            //channel.basicReject(message.getMessageProperties().getDeliveryTag(),true);
        }
        Message returnMsg = null;
        try {
            returnMsg = new Message("---返回数据---".getBytes("UTF-8"), message.getMessageProperties());
        }catch(Exception e){
            e.printStackTrace();
        }
        return message;
    }

    @RabbitListener(queues = I3CoreQueue.DEMO_ACK_QUEUE)
    public void processAck(String data, Channel channel, Message message) {
        try {
            System.out.println("【client】数据接收成功：" + data);

            /*if(data.startsWith("ack")){
                System.out.println("【client】数据抛出异常");
                throw new RuntimeException("【队列抛出异常】" + data);
            }*/
            //在队列删掉 不会再发了 否则消息服务器以为这条消息没处理掉 后续还会在发
            channel.basicAck(message.getMessageProperties().getDeliveryTag(),false);
        } catch (IOException e) {
            e.printStackTrace();            //丢弃这条消息
            // channel.basicNack(message.getMessageProperties().getDeliveryTag(), false,false);
            // System.out.println("receiver fail");
            try {
                channel.basicNack(message.getMessageProperties().getDeliveryTag(),false,true);
            } catch (IOException e1) {
                e1.printStackTrace();
            }
        }
    }
}
