package cn.estsh.i3plus.core.apiservice.serviceimpl.base;

import cn.estsh.i3plus.core.api.iservice.base.ISystemLoginService;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.shirotoken.AdminToken;
import cn.estsh.i3plus.pojo.base.shirotoken.SaAdminToken;
import cn.estsh.i3plus.pojo.base.shirotoken.UserToken;
import cn.estsh.i3plus.pojo.platform.bean.SessionUser;
import cn.estsh.i3plus.pojo.platform.bean.SysUser;
import cn.estsh.i3plus.pojo.platform.repository.SysUserRepository;
import cn.estsh.impp.framework.boot.auth.AuthUtil;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.exception.ImppExceptionEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * @Description : 用户登陆方法
 * @Reference :
 * @Author : alwaysfrin
 * @CreateDate : 2018-10-13 17:18
 * @Modify:
 **/
@Service
public class SystemLoginService implements ISystemLoginService {
    private static final Logger LOGGER = LoggerFactory.getLogger(SystemLoginService.class);

    @Autowired
    private SysUserRepository sysUserRDao;

    @Override
    public SessionUser queryUserLogin(String loginName, String loginPwd, String languageCode) {
        //生成令牌
        UserToken ut = new UserToken(loginName,loginPwd,languageCode);
        //token验证
        return AuthUtil.login(ut);
    }

    @Override
    public SessionUser queryAdminLogin(String loginName, String loginPwd, String languageCode) {
        //生成令牌
        AdminToken adminToken = new AdminToken(loginName,loginPwd,languageCode);
        //token验证
        return AuthUtil.login(adminToken);
    }

    @Override
    public SessionUser queryCheckUserLogin(UserToken userToken) {
        //验证用户
        SysUser user = getUserLoginInfo(userToken.getLoginName(),userToken.getLoginPwd());
        LOGGER.info("【验证用户checkUserLogin】{}",user);
        //未抛异常，封装用户
        return packSessionUser(user,CommonEnumUtil.USER_TYPE.USER.getCode(),userToken.getLanguageCode());
    }

    @Override
    public SessionUser queryCheckAdminLogin(AdminToken adminToken) {
        //验证用户
        SysUser user = getUserLoginInfo(adminToken.getLoginName(),adminToken.getLoginPwd());
        //未抛异常，封装用户
        return packSessionUser(user,CommonEnumUtil.USER_TYPE.ADMIN.getCode(),adminToken.getLanguageCode());
    }

    @Override
    public SessionUser queryCheckSaAdminLogin(SaAdminToken saAdminToken) {
        //SysUser user = getUserLoginInfo(saAdminToken.getLoginName(),saAdminToken.getLoginPwd());
        SysUser user = null;
        /**
         * to do
         *
         * 此处外网获取sa超级管理员用户名密码
         * 或者导入加密证书生成内存超级管理员用户名密码
         */
        return packSessionUser(user,CommonEnumUtil.USER_TYPE.SA.getCode(),saAdminToken.getLanguageCode());
    }

    /**
     * 根据用户名密码查询用户
     * @param loginName
     * @param pwd
     * @return
     */
    public SysUser getUserLoginInfo(String loginName,String pwd){
        SysUser user = sysUserRDao.getByProperty("loginName",loginName);
        if(user == null){
            //用户不存在
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.IMPP.getCode())
                    .setErrorCode(ImppExceptionEnum.LOGIN_EXCEPTION.getCode())
                    .setErrorDetail("用户不存在")
                    .setErrorSolution("重新登陆")
                    .build();
//        }else if(!StringUtils.equals(user.getLoginPwd(),pwd)){
//            //密码不符
//            throw ImppExceptionBuilder.newInstance()
//                    .setSystemID(CommonEnumUtil.SOFT_TYPE.IMPP.getCode())
//                    .setErrorCode(ImppExceptionEnum.LOGIN_EXCEPTION.getCode())
//                    .setErrorDetail("登陆密码错误")
//                    .setErrorSolution("重新输入")
//                    .build();
        }else if(!"123".equals(pwd)){
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.IMPP.getCode())
                    .setErrorCode(ImppExceptionEnum.LOGIN_EXCEPTION.getCode())
                    .setErrorDetail("登陆密码错误")
                    .setErrorSolution("重新输入")
                    .build();
        }

        return user;
    }

    /**
     * 封装用户登陆信息
     * @param user
     * @param userType
     * @param languageCode
     * @return
     */
    private SessionUser packSessionUser(SysUser user,String userType, String languageCode) {
        SessionUser sessionUser = new SessionUser();
        sessionUser.setLanguageCode(languageCode);
        sessionUser.setSiteCode(user.getFactoryCode());
        sessionUser.setUserName(user.getEmployeeNameRdd());
        sessionUser.setUserType(userType);
        sessionUser.setUserCode(user.getEmployeeCodeRdd());

        return sessionUser;
    }
}
