package cn.estsh.i3plus.core.apiservice.serviceimpl.busi;

import cn.estsh.i3plus.core.api.iservice.busi.ISysMenuService;
import cn.estsh.i3plus.core.apiservice.dao.ISysMenuDao;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.platform.bean.SessionUser;
import cn.estsh.i3plus.pojo.platform.bean.SysMenu;
import cn.estsh.i3plus.pojo.platform.repository.SysMenuRepository;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.exception.ImppExceptionEnum;
import cn.estsh.impp.framework.boot.util.ResultBean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Description : 系统功能业务接口实现 
 * @Reference   :
 * @Author      : wei.peng
 * @Date        : 2018-10-22 15:18:14.969
 * @Modify      :
 **/
@Service
public class SysMenuServiceImpl implements ISysMenuService {

    public static final Logger LOGGER = LoggerFactory.getLogger(SysMenuServiceImpl.class);

    @Autowired
    private SysMenuRepository sysMenuRepository;

    @Autowired
    private ISysMenuDao iSysMenuDao;

    @Override
    public void updateSysMenu(SysMenu sysMenu) {
        LOGGER.info("系统功能 SYS_MENU :{}", sysMenu);
        if(sysMenu != null){
            sysMenuRepository.update(sysMenu);
        }
        throw ImppExceptionBuilder.newInstance()
                .setSystemID(CommonEnumUtil.SOFT_TYPE.IMPP.getCode())
                .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION_DATA_EXIT.getCode())
                .setErrorDetail("数据不存在")
                .setErrorSolution("请重新操作")
                .build();
    }

    @Override
    public void updateSysMenuStatus(long id, int status, SessionUser user) {
        LOGGER.info("系统功能 SYS_MENU  id:{} status:{} user:{}", id,status,user);
        SysMenu menu = sysMenuRepository.getById(id);
        if(null != menu){
            menu.setMenuStatus(status);
            menu.setModifyUser(user.getUserName());
            sysMenuRepository.update(menu);
        }else{
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.IMPP.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION_DATA_EXIT.getCode())
                    .setErrorDetail("数据不存在")
                    .setErrorSolution("请重新操作")
                    .build();
        }
    }

    @Override
    public void deleteSysMenuById(long id) {
        LOGGER.info("系统功能 SYS_MENU Key:{}", id);
        //TODO 记录平台用户操作日志
        long count = iSysMenuDao.queryCountByParentId(id);
        if(count >= 1){
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.IMPP.getCode())
                    .setErrorCode(ImppExceptionEnum.BUSINESS_EXCEPTION_DATA_ERROR.getCode())
                    .setErrorDetail("数据存在子集")
                    .setErrorSolution("请删除子集在操作")
                    .build();

        }
        sysMenuRepository.deleteById(id);
    }

    @Override
    public SysMenu insertSysMenu(SysMenu sysMenu) {
        LOGGER.info("系统功能 SYS_MENU :{}", sysMenu);
        if(null != sysMenu.getMenuTypeId()){
            sysMenu.setRedMenuTypeName(CommonEnumUtil.METHOD_LEVEL.valueOf(sysMenu.getMenuTypeId()));
        }
        if(0 != sysMenu.getParentId()){
            SysMenu parent = sysMenuRepository.getById(sysMenu.getParentId());
            if(null != parent){
                sysMenu.setRedParentName(parent.getName());
            }

        }
        return sysMenuRepository.insert(sysMenu);
    }

    @Override
    public List<SysMenu> findSysMenuAll() {
        LOGGER.info("系统功能 SYS_MENU find All");
        return sysMenuRepository.findAll();
    }

    @Override
    public SysMenu getSysMenuById(long id) {
        LOGGER.info("系统功能 SYS_MENU find id:{}", id);
        return sysMenuRepository.getOne(id);
    }
}
