package cn.estsh.i3plus.core.apiservice.serviceimpl.busi;

import cn.estsh.i3plus.core.api.iservice.busi.ISysRoleService;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.platform.bean.SessionUser;
import cn.estsh.i3plus.pojo.platform.bean.SysRole;
import cn.estsh.i3plus.pojo.platform.repository.SysRoleRepository;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.exception.ImppExceptionEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Description : 系统角色业务接口实现
 * @Reference   :
 * @Author      : wei.peng
 * @Date        : 2018-10-22 16:58:43.779
 * @Modify      :
 **/
@Service
public class SysRoleServiceImpl implements ISysRoleService {

    public static final Logger LOGGER = LoggerFactory.getLogger(SysRoleServiceImpl.class);

    @Autowired
    private SysRoleRepository sysRoleRepository;

    @Override
    public void updateSysRole(SysRole sysRole) {
        LOGGER.info("系统角色 SYS_ROLE :{}", sysRole);
        sysRoleRepository.update(sysRole);
    }

    @Override
    public void updateSysRoleStatus(long id, int status, SessionUser user) {
        LOGGER.info("系统角色 SYS_MENU  id:{} status:{} user:{}", id,status,user);
        SysRole role = sysRoleRepository.getById(id);
        if(null != role){
            role.setRoleStatus(status);
            role.setModifyUser(user.getUserName());
            sysRoleRepository.update(role);
        }else {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.IMPP.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION_DATA_EXIT.getCode())
                    .setErrorDetail("数据不存在")
                    .setErrorSolution("请重新操作")
                    .build();
        }
    }

    @Override
    public void deleteSysRoleById(long id) {
        LOGGER.info("系统角色 SYS_ROLE Key:{}", id);
        sysRoleRepository.deleteById(id);
    }


    @Override
    public SysRole insertSysRole(SysRole sysRole) {
        LOGGER.info("系统角色 SYS_ROLE :{}", sysRole);
        return sysRoleRepository.insert(sysRole);
    }

    @Override
    public List<SysRole> findSysRoleAll() {
        LOGGER.info("系统角色 SYS_ROLE find All");
        return sysRoleRepository.findAll();
    }

    @Override
    public SysRole getSysRoleById(long id) {
        LOGGER.info("系统角色 SYS_ROLE find id:{}", id);
        return sysRoleRepository.getOne(id);
    }
}
