package cn.estsh.i3plus.core.apiservice.serviceimpl.busi;

import cn.estsh.i3plus.core.api.iservice.busi.ISystemResourceService;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.bean.ListPager;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.base.common.PagerHelper;
import cn.estsh.i3plus.pojo.platform.bean.SysLocaleLanguage;
import cn.estsh.i3plus.pojo.platform.bean.SysLocaleResource;
import cn.estsh.i3plus.pojo.platform.repository.SysLocaleLanguageRepository;
import cn.estsh.i3plus.pojo.platform.repository.SysLocaleResourceRepository;
import cn.estsh.i3plus.pojo.platform.sqlpack.CoreHqlPack;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;

/**
 * @Description : 系统资源服务
 * @Reference :
 * @Author : alwaysfrin
 * @CreateDate : 2018-10-11 17:00
 * @Modify:
 **/
@Service
public class SystemResourceService implements ISystemResourceService {

    @Autowired
    private SysLocaleLanguageRepository sysLocaleLanguageRDao;

    @Autowired
    private SysLocaleResourceRepository sysLocaleResourceRDao;

    @Override
    public SysLocaleLanguage insertSysLocaleLanguage(SysLocaleLanguage lang) {
        return sysLocaleLanguageRDao.insert(lang);
    }

    @Override
    public SysLocaleLanguage updateSysLocaleLanguage(SysLocaleLanguage lang) {
        return sysLocaleLanguageRDao.save(lang);
    }

    @Override
    public void deleteSysLocaleLanguageById(long id) {
        sysLocaleLanguageRDao.deleteById(id);
    }

    @Override
    public List<SysLocaleLanguage> listSysLocaleLanguage(SysLocaleLanguage lang) {
        if(lang == null){
            return sysLocaleLanguageRDao.list();
        }else {
            return sysLocaleLanguageRDao.findByProperty(
                    new String[]{"languageCode", "languageName", "isDefault"},
                    new Object[]{lang.getLanguageCode(), lang.getLanguageName(), lang.getIsDefault()});
        }
    }

    @Override
    public ListPager<SysLocaleLanguage> listSysLocaleLanguageByPager(SysLocaleLanguage lang, Pager pager) {
        if(lang == null) {
            pager = PagerHelper.getPager(pager, sysLocaleLanguageRDao.listCount());
            return new ListPager(sysLocaleLanguageRDao.listPager(pager),pager);
        }else {
            String hqlPack = CoreHqlPack.packHqlSysLocaleLanguage(lang);
            pager = PagerHelper.getPager(pager, sysLocaleLanguageRDao.findByHqlWhereCount(hqlPack));
            return new ListPager(sysLocaleLanguageRDao.findByHqlWherePage(hqlPack + lang.getOrderByParam(),pager),pager);
        }
    }

    @Override
    public SysLocaleResource insertSysLocaleResource(SysLocaleResource res) {
        return sysLocaleResourceRDao.insert(res);
    }

    @Override
    public SysLocaleResource updateSysLocaleResource(SysLocaleResource res) {
        return sysLocaleResourceRDao.save(res);
    }

    @Override
    public void deleteSysLocaleResourceById(long id) {
        sysLocaleResourceRDao.deleteById(id);
    }

    @Override
    public void deleteSysLocaleResourceByIds(String[] ids){
        for(String idStr : ids){
            sysLocaleResourceRDao.deleteById(Long.parseLong(idStr));
        }
    }

    @Override
    public ListPager<SysLocaleResource> listSysLocaleResourceByPager(SysLocaleResource res, Pager pager) {
        if(res == null){
            //不传入实体对象，查询所有
            int count = sysLocaleResourceRDao.listCount();
            pager = PagerHelper.getPager(pager,count);
            return new ListPager(sysLocaleResourceRDao.listPager(pager),pager);
        }else {
            //生成hql查询语句
            String hqlPack = CoreHqlPack.packHqlSysLocaleResource(res);
            pager = PagerHelper.getPager(pager,sysLocaleResourceRDao.findByHqlWhereCount(hqlPack));
            return new ListPager(sysLocaleResourceRDao.findByHqlWherePage(hqlPack + res.orderBy(), pager),pager);
        }
    }

    @Override
    public List<SysLocaleResource> listSysLocaleResource(SysLocaleResource res) {
        if(res == null){
            return sysLocaleResourceRDao.list();
        }else {
            return sysLocaleResourceRDao.findByProperty(
                    new String[]{"resourceType", "languageCode", "resourceKey", "resourceValue", "isSystem", "isDefault"},
                    new Object[]{res.getResourceType(), res.getLanguageCode(), res.getResourceKey(), res.getResourceValue(), res.getIsSystem(), res.getIsDefault()});
        }
    }

    @Override
    public SysLocaleResource getSysLocaleResourceByLanguage(int resourceType,String langCode,String resKey) {
        List<SysLocaleResource> resList = sysLocaleResourceRDao.findByProperty(
                new String[]{"resourceType", "languageCode", "resourceKey"},
                new Object[]{resourceType,langCode, resKey});

        if(CollectionUtils.isEmpty(resList)){
            //不存在，则使用默认的
            resList = sysLocaleResourceRDao.findByProperty(
                    new String[]{"resourceType", "resourceKey", "isDefault"},
                    new Object[]{resourceType,resKey, CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue()});
        }
        if(resList.size() > 0) {
            return resList.iterator().next();
        }else{
            return null;
        }
    }
}
